#ifndef NT2_INCLUDE_CONSTANTS_DIGAMMALARGELIM_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_DIGAMMALARGELIM_HPP_INCLUDED

#include <nt2/euler/include/constants/digammalargelim.hpp>

#endif
